Welcome to paged-list's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   api
   examples

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
